==> haskell-tidal-1.9.5-109.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tidal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tidal
version:              1.9.5
visibility:           public
id:                   tidal-1.9.5-2n5maInzrBmDMPTacPQmP8
key:                  tidal-1.9.5-2n5maInzrBmDMPTacPQmP8
license:              GPL-3.0-only
copyright:            (c) Alex McLean and other contributors, 2021
maintainer:
    Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>

author:               Alex McLean
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding patterns.

category:             Sound
abi:                  56c388c41a3c04d0f493edd9956c9031
exposed:              True
exposed-modules:
    Paths_tidal Sound.Tidal.Bjorklund Sound.Tidal.Chords
    Sound.Tidal.Config Sound.Tidal.Context Sound.Tidal.Control
    Sound.Tidal.Core Sound.Tidal.ID Sound.Tidal.Params
    Sound.Tidal.ParseBP Sound.Tidal.Pattern Sound.Tidal.Safe.Boot
    Sound.Tidal.Safe.Context Sound.Tidal.Scales Sound.Tidal.Show
    Sound.Tidal.Simple Sound.Tidal.Stream Sound.Tidal.StreamTypes
    Sound.Tidal.Tempo Sound.Tidal.Time Sound.Tidal.Transition
    Sound.Tidal.UI Sound.Tidal.Utils Sound.Tidal.Version

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tidal-1.9.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tidal-1.9.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tidal-1.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tidal
hs-libraries:         HStidal-1.9.5-2n5maInzrBmDMPTacPQmP8
depends:
    base-4.18.2.1 bytestring-0.11.5.3 clock-0.8.4-DWXp61AeHFIv4cYLkfaEg
    colour-2.3.6-H6QKK8UT9PiEnQ6wB0s1YD containers-0.6.7
    deepseq-1.4.8.1 exceptions-0.10.7 hosc-0.20-3KWVxGsw5D69NLmMI2o1j9
    mtl-2.3.1 network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe parsec-3.1.16.1
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm text-2.0.2
    tidal-link-1.0.3-BhLvLtes61CGmsoGsSKCkr transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-tidal/html/tidal.haddock
haddock-html:         /usr/share/doc/haskell-tidal/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tidal-1.9.5-110-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-tidal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tidal
version:              1.9.5
visibility:           public
id:                   tidal-1.9.5-DxcP8HmN7lXIRyHj6hfZgE
key:                  tidal-1.9.5-DxcP8HmN7lXIRyHj6hfZgE
license:              GPL-3.0-only
copyright:            (c) Alex McLean and other contributors, 2021
maintainer:
    Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>

author:               Alex McLean
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding patterns.

category:             Sound
abi:                  329b1b0f95c959bdc28f4f1966c77025
exposed:              True
exposed-modules:
    Paths_tidal Sound.Tidal.Bjorklund Sound.Tidal.Chords
    Sound.Tidal.Config Sound.Tidal.Context Sound.Tidal.Control
    Sound.Tidal.Core Sound.Tidal.ID Sound.Tidal.Params
    Sound.Tidal.ParseBP Sound.Tidal.Pattern Sound.Tidal.Safe.Boot
    Sound.Tidal.Safe.Context Sound.Tidal.Scales Sound.Tidal.Show
    Sound.Tidal.Simple Sound.Tidal.Stream Sound.Tidal.StreamTypes
    Sound.Tidal.Tempo Sound.Tidal.Time Sound.Tidal.Transition
    Sound.Tidal.UI Sound.Tidal.Utils Sound.Tidal.Version

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tidal-1.9.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tidal-1.9.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tidal-1.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tidal
hs-libraries:         HStidal-1.9.5-DxcP8HmN7lXIRyHj6hfZgE
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    clock-0.8.4-IMsJrS0UrDMF6MHHHvKozA
    colour-2.3.6-DLRFrLUBudd2Y8gC5KfK2z containers-0.6.7
    deepseq-1.4.8.1 exceptions-0.10.7 hosc-0.20-60knS8tGnT68SLkZfIWLz2
    mtl-2.3.1 network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ parsec-3.1.16.1
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj text-2.0.2
    tidal-link-1.0.3-BhLvLtes61CGmsoGsSKCkr transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-tidal/html/tidal.haddock
haddock-html:         /usr/share/doc/haskell-tidal/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
